# OctoprintEnvironment


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**os** | [**OctoprintPlatform**](OctoprintPlatform.md) |  | 
**python** | [**OctoprintPython**](OctoprintPython.md) |  | 
**hardware** | [**OctoprintHardware**](OctoprintHardware.md) |  | 
**pi_support** | [**OctoprintPiSupport**](OctoprintPiSupport.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


